@@ -17,7 +17,6 @@ from pathlib import Path
 from subprocess import CalledProcessError
 from threading import Thread
 from time import sleep
-from typing import List
 from urllib.parse import urldefrag, urlsplit, urlunsplit
 from uuid import uuid4
 
@@ -75,8 +74,6 @@ class _AiidaLabApp:
     metadata: dict
     name: str
     path: Path
-    logo: str = field(default_factory=str)
-    categories: List[str] = field(default_factory=list)
     releases: dict = field(default_factory=dict)
 
     @classmethod
@@ -86,33 +83,24 @@ class _AiidaLabApp:
             **{
                 key: value
                 for key, value in registry_entry.items()
-                if key in ("categories", "logo", "metadata", "name", "releases")
+                if key in ("metadata", "name", "releases")
             },
         )
 
-    @staticmethod
-    def _migrate_registry_entry_to_v1(entry):
-        entry["logo"] = entry["metadata"].pop("logo", None)
-        entry["categories"] = entry["metadata"].pop("categories", None)
-        return entry
-
     @classmethod
     def _registry_entry_from_path(cls, path):
         try:
-            entry = {
+            return {
                 "name": path.stem,
                 "metadata": asdict(Metadata.parse(path)),
                 "releases": None,
             }
-            return cls._migrate_registry_entry_to_v1(entry)
-        except TypeError:
+        except (TypeError, ValueError):
             logger.debug(f"Unable to parse metadata from '{path}'")
             return {
                 "name": path.stem,
                 "metadata": dict(title=path.stem, description=""),
                 "releases": None,
-                "logo": None,
-                "categories": None,
             }
 
     @classmethod
@@ -182,7 +170,15 @@ class _AiidaLabApp:
         """The app is installed if the corresponding folder is present."""
         return self.path.exists()
 
-    def remote_update_status(self):
+    def remote_update_status(self, prereleases=False):
+        """Determine the remote update satus.
+
+        Arguments:
+            prereleases (Bool):
+                Set to True to include available preleases. Defaults to False.
+        Returns:
+            AppRemoteUpdateStatus
+        """
         if self.is_installed():
 
             # Check whether app is registered.
@@ -198,7 +194,11 @@ class _AiidaLabApp:
                 return AppRemoteUpdateStatus.DETACHED
 
             # Check whether the locally installed version is the latest release.
-            available_versions = list(sorted(self.releases, key=parse, reverse=True))
+            available_versions = [
+                version
+                for version in sorted(self.releases, key=parse, reverse=True)
+                if prereleases or not parse(version).is_prerelease
+            ]
             if len(available_versions) and installed_version != available_versions[0]:
                 return AppRemoteUpdateStatus.UPDATE_AVAILABLE
 
@@ -330,13 +330,22 @@ class _AiidaLabApp:
         git_clone(base_url, ref, self.path)
 
     def install(
-        self, version=None, python_bin=None, install_dependencies=True, stdout=None
+        self,
+        version=None,
+        python_bin=None,
+        install_dependencies=True,
+        stdout=None,
+        prereleases=False,
     ):
         if version is None:
             try:
-                version = list(sorted(self.releases, key=parse))[-1]
+                version = [
+                    version
+                    for version in sorted(self.releases, key=parse)
+                    if prereleases or not parse(version).is_prerelease
+                ][-1]
             except IndexError:
-                raise ValueError("No versions available for '{self}'.")
+                raise ValueError(f"No versions available for '{self}'.")
         if python_bin is None:
             python_bin = sys.executable
 
@@ -553,7 +562,8 @@ class AiidaLabApp(traitlets.HasTraits):
         super().__init__()
 
         self.name = self._app.name
-        self.logo = self._app.logo
+        self.logo = self._app.metadata["logo"]
+        self.categories = self._app.metadata["categories"]
         self.is_installed = self._app.is_installed
         self.path = str(self._app.path)
         self.refresh_async()
@@ -599,7 +609,7 @@ class AiidaLabApp(traitlets.HasTraits):
 
     def in_category(self, category):
         # One should test what happens if the category won't be defined.
-        return category in self._registry_data.categories
+        return category in self.categories
 
     def _has_git_repo(self):
         """Check if the app has a .git folder in it."""
@@ -612,7 +622,9 @@ class AiidaLabApp(traitlets.HasTraits):
     def install_app(self, version=None, stdout=None):
         """Installing the app."""
         with self._show_busy():
-            self._app.install(version=version, stdout=stdout)
+            self._app.install(
+                version=version, stdout=stdout, prereleases=self.include_prereleases
+            )
             FIND_INSTALLED_PACKAGES_CACHE.clear()
             self.refresh()
             return self._installed_version()
@@ -699,7 +711,12 @@ class AiidaLabApp(traitlets.HasTraits):
                 self.set_trait(
                     "compatible", self._is_compatible(self.installed_version)
                 )
-                self.set_trait("remote_update_status", self._app.remote_update_status())
+                self.set_trait(
+                    "remote_update_status",
+                    self._app.remote_update_status(
+                        prereleases=self.include_prereleases
+                    ),
+                )
                 self.set_trait(
                     "detached",
                     (self.installed_version is AppVersion.UNKNOWN)
